# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['plato_helper_py']

package_data = \
{'': ['*'],
 'plato_helper_py': ['.scannerwork/*',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb']}

install_requires = \
['backoff>=2.2,<3.0', 'requests>=2.27,<3.0', 'types-requests>=2.28.11,<3.0.0']

setup_kwargs = {
    'name': 'plato-helper-py',
    'version': '2.1.0',
    'description': 'Helper for the Plato microservice',
    'long_description': None,
    'author': 'Tiago Santos',
    'author_email': 'tiago.santos@vizidox.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)
